@@ -25,16 +25,16 @@
 #'
 #' set.seed(2)
 #' rf_fit <-
-#'   rand_forest() %>%
-#'   set_mode("classification") %>%
-#'   set_engine("randomForest") %>%
+#'   rand_forest() |>
+#'   set_mode("classification") |>
+#'   set_engine("randomForest") |>
 #'   fit(class ~ ., data = tr_dat)
 #'
 #' cal_pred <-
-#'   predict(rf_fit, cal_dat, type = "prob") %>%
+#'   predict(rf_fit, cal_dat, type = "prob") |>
 #'   bind_cols(cal_dat)
 #' te_pred <-
-#'   predict(rf_fit, te_dat, type = "prob") %>%
+#'   predict(rf_fit, te_dat, type = "prob") |>
 #'   bind_cols(te_dat)
 #'
 #' cal_plot_windowed(cal_pred, truth = class, window_size = 0.1, step_size = 0.03)
@@ -67,17 +67,33 @@ cal_estimate_multinomial.data.frame <-
            .by = NULL) {
     stop_null_parameters(parameters)
 
-    group <- get_group_argument({{ .by }}, .data)
-    .data <- dplyr::group_by(.data, dplyr::across({{ group }}))
-
-    truth <- enquo(truth)
-    cal_multinom_impl(
-      .data = .data,
-      truth = !!truth,
+    info <- get_prediction_data(
+      .data,
+      truth = {{ truth }},
       estimate = {{ estimate }},
+      .by = {{ .by }}
+    )
+
+    model <- mtnml_fit_over_groups(info, smooth, ...)
+
+    if (smooth) {
+      method <- "Generalized additive model calibration"
+      additional_class <- c("cal_estimate_multinomial_spline",
+                            "cal_estimate_multinomial")
+    } else {
+      method <- "Multinomial regression calibration"
+      additional_class <- "cal_estimate_multinomial"
+    }
+
+    as_cal_object(
+      estimate = model,
+      levels = info$map,
+      truth = info$truth,
+      method = method,
+      rows = nrow(info$predictions),
+      additional_classes = additional_class,
       source_class = cal_class_name(.data),
-      smooth = smooth,
-      ...
+      type = "multiclass"
     )
   }
 
@@ -90,24 +106,27 @@ cal_estimate_multinomial.tune_results <-
            smooth = TRUE,
            parameters = NULL,
            ...) {
-    tune_args <- tune_results_args(
-      .data = .data,
-      truth = {{ truth }},
-      estimate = {{ estimate }},
-      event_level = "first",
-      parameters = parameters,
-      ...
-    )
 
-    tune_args$predictions %>%
-      dplyr::group_by(!!tune_args$group) %>%
-      cal_multinom_impl(
-        truth = !!tune_args$truth,
-        estimate = !!tune_args$estimate,
-        source_class = cal_class_name(.data),
-        smooth = smooth,
-        ...
-      )
+    info <- get_tune_data(.data, parameters)
+
+    model <- mtnml_fit_over_groups(info, smooth, ...)
+
+    if (!smooth) {
+      model_label <- "Multinomial regression calibration"
+    } else {
+      model_label <- "Generalized additive model calibration"
+    }
+
+    as_cal_object(
+      estimate = model,
+      levels = info$map,
+      truth = info$truth,
+      method = model_label,
+      rows = nrow(info$predictions),
+      additional_classes = "cal_estimate_multinomial",
+      source_class = cal_class_name(.data),
+      type = "multiclass"
+    )
   }
 
 #' @export
@@ -121,117 +140,76 @@ cal_estimate_multinomial.grouped_df <- function(.data,
   abort_if_grouped_df()
 }
 
+#' @rdname required_pkgs.cal_object
+#' @keywords internal
+#' @export
+required_pkgs.cal_estimate_multinomial_spline <- function(x, ...) {
+  check_req_pkgs(x, unsmooth = "nnet")
+}
+
 #' @rdname required_pkgs.cal_object
 #' @keywords internal
 #' @export
 required_pkgs.cal_estimate_multinomial <- function(x, ...) {
-  c("nnet", "probably")
+  # for legacy objects that all have this class.
+  check_req_pkgs(x, unsmooth = "nnet")
 }
 
-cal_multinom_impl <- function(.data, truth, estimate, source_class, smooth, ...) {
-  truth <- enquo(truth)
-
-  levels <- truth_estimate_map(.data, !!truth, {{ estimate }})
-
-  if (length(levels) == 2) {
-    rlang::abort(
-      "This function is meant to be used with a multi-class outcomes only"
-    )
-  }
-
-  model <- cal_multinom_impl_grp(
-    .data = .data,
-    truth = !!truth,
-    levels = levels,
-    smooth = smooth,
-    ...
-  )
-
-  as_cal_object(
-    estimate = model,
-    levels = levels,
-    truth = !!truth,
-    method = if (!smooth) "Multinomial regression" else "Generalized additive model",
-    rows = nrow(.data),
-    additional_classes = "cal_estimate_multinomial",
-    source_class = source_class,
-    type = "multiclass"
-  )
-}
-
-
-cal_multinom_impl_grp <- function(.data, truth, levels, smooth, ...) {
-  truth <- enquo(truth)
-  .data %>%
-    split_dplyr_groups() %>%
-    lapply(
-      function(x) {
-        estimate <- cal_multinom_impl_single(
-          .data = x$data,
-          truth = !!truth,
-          levels = levels,
-          smooth = smooth,
-          ... = ...
-        )
-        list(
-          filter = x$filter,
-          estimate = estimate
-        )
-      }
-    )
-}
-
-cal_multinom_impl_single <- function(.data,
-                                     truth = NULL,
-                                     levels = NULL,
-                                     smooth = TRUE,
-                                     ...) {
-  truth <- enquo(truth)
-  num_lvls <- length(levels)
-  levels <- levels[1:(length(levels) - 1)]
-
-  if (smooth) {
-    # multinomial gams in mgcv needs zero-based integers as the outcome
-
-    class_col <- deparse(ensym(truth))
-    .data[[class_col]] <- as.numeric(.data[[class_col]]) - 1
-    max_int <- max(.data[[class_col]], na.rm = TRUE)
-
-    # It also needs a list of formulas, one for each level, and the first one
-    # requires a LHS
-
-    smooths <- purrr::map(levels, ~ call2(.fn = "s", expr(!!.x)))
-    rhs_f <- purrr::reduce(smooths, function(x, y) expr(!!x + !!y))
-    rhs_only <- new_formula(lhs = NULL, rhs = rhs_f)
-    both_sides <- new_formula(lhs = ensym(truth), rhs = rhs_f)
-    all_f <- purrr::map(seq_along(levels), ~rhs_only)
-    all_f[[1]] <- both_sides
-
-    model <- mgcv::gam(all_f, data = .data, family = mgcv::multinom(max_int))
-
-    # Nuke environments saved in formulas
-    # # TODO This next line causes a failure for unknown reasons. Look into it more
-    # model$formula <- purrr::map(model$formula, clean_env)
-    model$terms <- clean_env(model$terms)
-  } else {
-    levels_formula <- purrr::reduce(
-      levels,
-      function(x, y) expr(!!x + !!y)
-    )
-
-    f_model <- expr(!!ensym(truth) ~ !!levels_formula)
-
-    prevent_output <- utils::capture.output(
-      model <- nnet::multinom(formula = f_model, data = .data, ...)
-    )
-    model$terms <- clean_env(model$terms)
-  }
-
-
-  model
+#' @rdname required_pkgs.cal_object
+#' @keywords internal
+#' @export
+required_pkgs.cal_estimate_multinomial <- function(x, ...) {
+  check_req_pkgs(x, unsmooth = "nnet")
 }
 
 clean_env <- function(x) {
   attr(x, ".Environment") <- rlang::base_env()
   x
 }
+
+fit_multinomial_model <- function(.data, smooth, estimate, outcome, ...) {
+  smooth <- turn_off_smooth_if_too_few_unique(.data, estimate, smooth)
+
+  if (smooth) {
+    # multinomial gams in mgcv needs zero-based integers as the outcome
+    .data[[outcome]] <- as.numeric(.data[[outcome]]) - 1
+    max_int <- max(.data[[outcome]], na.rm = TRUE)
+
+    f <- multinomial_f_from_str(outcome, estimate)
+    # TODO check for failures
+    model <- mgcv::gam(f, data = .data, family = mgcv::multinom(max_int), ...)
+    model$terms <- clean_env(model$terms)
+  } else {
+    f <- f_from_str(outcome, estimate[-length(estimate)])
+    # TODO check for failures
+    prevent_output <- utils::capture.output(
+      model <- nnet::multinom(formula = f, data = .data, ...)
+    )
+    model$terms <- clean_env(model$terms)
+  }
+
+  model
+}
+
+
+mtnml_fit_over_groups <- function(info, smooth = TRUE, ...) {
+  if (length(info$levels) == 2) {
+    cli::cli_abort("This function is meant to be used with multi-class outcomes only.")
+  }
+
+  grp_df <- make_group_df(info$predictions, group = info$group)
+  nst_df <- vctrs::vec_split(x = info$predictions, by = grp_df)
+  fltrs <- make_cal_filters(nst_df$key)
+
+  fits <-
+    lapply(
+      nst_df$val,
+      fit_multinomial_model,
+      smooth = smooth,
+      estimate = info$estimate,
+      info$truth,
+      ...
+    )
+
+  purrr::map2(fits, fltrs, ~ list(filter = .y, estimate = .x))
+}
