@@ -31,7 +31,7 @@
 #' @references
 #' Romano, Yaniv, Evan Patterson, and Emmanuel Candes. "Conformalized quantile
 #' regression." _Advances in neural information processing systems_ 32 (2019).
-#' @examplesIf !probably:::is_cran_check()
+#' @examplesIf !probably:::is_cran_check() & rlang::is_installed(c("modeldata", "parsnip", "quantregForest"))
 #' library(workflows)
 #' library(dplyr)
 #' library(parsnip)
@@ -42,16 +42,16 @@
 #' set.seed(2)
 #' sim_train <- sim_regression(500)
 #' sim_cal <- sim_regression(200)
-#' sim_new <- sim_regression(5) %>% select(-outcome)
+#' sim_new <- sim_regression(5) |> select(-outcome)
 #'
 #' # We'll use a neural network model
 #' mlp_spec <-
-#'   mlp(hidden_units = 5, penalty = 0.01) %>%
+#'   mlp(hidden_units = 5, penalty = 0.01) |>
 #'   set_mode("regression")
 #'
 #' mlp_wflow <-
-#'   workflow() %>%
-#'   add_model(mlp_spec) %>%
+#'   workflow() |>
+#'   add_model(mlp_spec) |>
 #'   add_formula(outcome ~ .)
 #'
 #' mlp_fit <- fit(mlp_wflow, data = sim_train)
@@ -138,7 +138,7 @@ quant_train <- function(train_data, y_name, ...) {
   cl <- rlang::call2(
     "quantregForest",
     .ns = "quantregForest",
-    x = quote(train_data %>% select(-dplyr::all_of(y_name))),
+    x = quote(train_data |> select(-dplyr::all_of(y_name))),
     y = quote(train_data[[y_name]]),
     ...
   )
