@@ -28,7 +28,7 @@
 #' @references
 #' Lei, Jing, et al. "Distribution-free predictive inference for regression."
 #' _Journal of the American Statistical Association_ 113.523 (2018): 1094-1111.
-#' @examplesIf !probably:::is_cran_check()
+#' @examplesIf !probably:::is_cran_check() & rlang::is_installed(c("modeldata", "parsnip", "nnet"))
 #' library(workflows)
 #' library(dplyr)
 #' library(parsnip)
@@ -39,16 +39,16 @@
 #' set.seed(2)
 #' sim_train <- sim_regression(500)
 #' sim_cal <- sim_regression(200)
-#' sim_new <- sim_regression(5) %>% select(-outcome)
+#' sim_new <- sim_regression(5) |> select(-outcome)
 #'
 #' # We'll use a neural network model
 #' mlp_spec <-
-#'   mlp(hidden_units = 5, penalty = 0.01) %>%
+#'   mlp(hidden_units = 5, penalty = 0.01) |>
 #'   set_mode("regression")
 #'
 #' mlp_wflow <-
-#'   workflow() %>%
-#'   add_model(mlp_spec) %>%
+#'   workflow() |>
+#'   add_model(mlp_spec) |>
 #'   add_formula(outcome ~ .)
 #'
 #' mlp_fit <- fit(mlp_wflow, data = sim_train)
@@ -65,7 +65,7 @@ int_conformal_split <- function(object, ...) {
 #' @export
 #' @rdname int_conformal_split
 int_conformal_split.default <- function(object, ...) {
-  rlang::abort("No known 'int_conformal_split' methods for this type of object.")
+  cli::cli_abort("No known {.fn int_conformal_split} methods for this type of object.")
 }
 
 #' @export
