@@ -5,7 +5,6 @@
 #' @import rlang
 #' @import vctrs
 #' @import ggplot2
-#' @importFrom dplyr %>%
 #' @importFrom purrr map
 #' @importFrom utils head
 #' @importFrom yardstick sens spec j_index
@@ -17,5 +16,5 @@ utils::globalVariables(c(
   ".bin", ".is_val", "event_rate", "events", "lower",
   "predicted_midpoint", "total", "upper", ".config",
   ".adj_estimate", ".rounded", ".pred", ".bound", "pred_val", ".extracts",
-  ".x", ".type", ".metrics"
+  ".x", ".type", ".metrics", "cal_data"
 ))
