@@ -16,9 +16,9 @@ test_that("split conformal intervals", {
   sim_new <- sim_regression(2)
 
   wflow <-
-    workflow() %>%
-    add_model(parsnip::linear_reg()) %>%
-    add_formula(outcome ~ .) %>%
+    workflow() |>
+    add_model(parsnip::linear_reg()) |>
+    add_formula(outcome ~ .) |>
     fit(sim_data)
 
   # ------------------------------------------------------------------------------
